'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var Vue = _interopDefault(require('vue'));

var originalContent = undefined;
var textColorDefault = '#fff';
var bgColorDefault = '#009688';

function selectPattern(word, liveHighlighting) {
  if ( liveHighlighting === void 0 ) liveHighlighting = false;

  var result = "";
  if (!liveHighlighting) {
    result = "\\b(" + word + ")\\b";
  } else {
    result = "(" + word + ")";
  }
  return result;
}

function testTextColor(color) {
  if ( color === void 0 ) color = textColorDefault;

  var result = textColorDefault;
  if (testColor(color)) {
    result = color;
  }
  return result;
}

function testBgColor(color) {
  if ( color === void 0 ) color = bgColorDefault;

  var result = bgColorDefault;
  if (testColor(color)) {
    result = color;
  }
  return result;
}

function testColor(color) {
  var result = false;
  var isAColor = /(^#[0-9A-F]{6}$)|(^#[0-9A-F]{3}$)/i.test(color);
  var isAString = /^[a-zA-Z]+$/.test(color);
  if (isAColor || isAString) {
    result = true;
  }
  return result;
}

function highlight(content, word, color, bgColor, patternSelected) {
  var spanStart = "<span style='padding:0px 5px; background-color:" + bgColor + "; color:" + color + "'>";
  var spanEnd = "</span>";
  var result = content;
  if (word != "") {
    var regex = new RegExp(patternSelected, "g");
    result = content.replace(regex, spanStart + "$&" + spanEnd);
  }
  return result;
}

var vueHighlighter = {
  bind: function bind(el, binding, vnode) {
    originalContent = el.innerHTML;
    var pattern = '';
    var word = '';
    var color = textColorDefault;
    var bgColor = bgColorDefault;
    if (binding.value.word != undefined) {
      word = binding.value.word;
    }
    if (binding.value.live != undefined) {
      pattern = selectPattern(word, binding.value.live);
    }
    if (binding.value.style != undefined) {
      color = testTextColor(binding.value.style.color);
    }
    if (binding.value.style != undefined) {
      bgColor = testBgColor(binding.value.style.bgColor);
    }
    el.innerHTML = highlight(originalContent, word, color, bgColor, pattern);
  },
  update: function update(el, binding, vnode, oldVnode) {
    var pattern = '';
    var color = textColorDefault;
    var bgColor = bgColorDefault;
    if (binding.value.style != undefined) {
      color = testTextColor(binding.value.style.color);
    }
    if (binding.value.style != undefined) {
      bgColor = testBgColor(binding.value.style.bgColor);
    }
    if (binding.value.live) {
      pattern = selectPattern(binding.value.word, binding.value.word);
      el.innerHTML = highlight(el.textContent, binding.value.word, color, bgColor, pattern);
    } else {
      pattern = selectPattern(binding.value.word, binding.value.live);
      el.innerHTML = highlight(originalContent, binding.value.word, color, bgColor, pattern);
    }
  },
  unbind: function unbind(el, binding, vnode) {
    el.innerHTML = originalContent;
  }
};

Vue.directive("highlight", vueHighlighter);

module.exports = vueHighlighter;
